Session

Struct Session 

pub struct Session { /* private fields */ }
A session with the Wallet Bridge.

Implementations

Source

impl Session

pub async fn new<V: SolValue + Send>( app_id: &AppId, action: &str, verification_level: VerificationLevel, bridge_url: BridgeUrl, signal: V, action_description: Option<&str>, ) -> Result<Self, Error>

Create a new session with the Wallet Bridge.

Errors

Returns an error if the request to the bridge fails, or if the response from the bridge is malformed.

pub fn connect_url(&self) -> Url

Returns the URL that the user should be directed to in order to connect their World App to the client.

pub async fn poll_for_status(&self) -> Result<Status, Error>

Polls the bridge for the status of the request, and returns the current status. You should call this method repeatedly until it returns Status::Confirmed or Status::Failed. Calling it again after leads to undefined behaviour.

Errors

Returns an error if the request to the bridge fails, or if the response from the bridge is malformed.