pub struct Proof {
pub proof: String,
pub merkle_root: String,
pub nullifier_hash: String,
pub verification_level: VerificationLevel,
}Expand description
The proof of verification returned by the World ID protocol.
Fields
proof: StringThe Zero-knowledge proof of the verification. A hex string, ABI encoded.
merkle_root: StringThe hash pointer to the root of the Merkle tree that proves membership of the user’s identity in the list of identities verified by the Orb. A hex string, ABI encoded.
nullifier_hash: StringEssentially the user’s unique identifier for your app (and specific action if using Incognito Actions). A hex string, ABI encoded.
verification_level: VerificationLevelEither orb or device.